@@ -10,7 +10,6 @@ Boxer::Part::Reclass - software component as a reclass node or class
 
 use v5.14;
 use utf8;
-use strictures 2;
 use Role::Commons -all;
 use namespace::autoclean 0.16;
 use autodie;
@@ -20,15 +19,18 @@ use MooX::StrictConstructor;
 extends qw(Boxer::Part);
 
 use Types::Standard qw(Str Maybe ArrayRef HashRef);
-use Types::TypeTiny qw(StringLike);
+use Boxer::Types qw( Suite );
+
+use strictures 2;
+no warnings "experimental::signatures";
 
 =head1 VERSION
 
-Version v1.4.0
+Version v1.4.1
 
 =cut
 
-our $VERSION = "v1.4.0";
+our $VERSION = "v1.4.1";
 
 =head1 DESCRIPTION
 
@@ -96,7 +98,7 @@ has tweak => (
 
 has epoch => (
 	is  => 'ro',
-	isa => Maybe [StringLike],
+	isa => Suite,
 );
 
 =head1 AUTHOR
