@@ -6,22 +6,23 @@ package Boxer::Role::Interact;
 
 use v5.14;
 use utf8;
-use strictures 2;
-use version;
 use Role::Commons -all;
+use namespace::autoclean 0.16;
 
 use Moo::Role;
+
 use Types::Standard qw< Bool >;
 
-use namespace::autoclean 0.16;
+use strictures 2;
+no warnings "experimental::signatures";
 
 =head1 VERSION
 
-Version v1.2.0
+Version v1.4.1
 
 =cut
 
-our $VERSION = version->declare("v1.2.0");
+our $VERSION = "v1.4.1";
 
 has verbose => (
 	is       => 'rw',
