@@ -4,49 +4,54 @@ package Boxer::Task::Classify;
 
 =cut
 
-use v5.14;
+use v5.20;
 use utf8;
-use strictures 2;
-use version;
 use Role::Commons -all;
+use feature 'signatures';
+no warnings "experimental::signatures";
+use namespace::autoclean 0.16;
 use autodie qw(:all);
 use IPC::System::Simple;
 
 use File::BaseDir qw(data_dirs);
-use Capture::Tiny qw(capture_stdout);
-use YAML::XS;
-use Boxer::World::Reclass;
-use Boxer::Part::Reclass;
+use Boxer;
 
 use Moo;
-use Types::Standard qw( Maybe Str Undef );
-use Boxer::Types qw( DataDir ClassDir NodeDir Suite );
-extends 'Boxer::Task';
+use MooX::StrictConstructor;
+extends qw(Boxer::Task);
 
-use namespace::autoclean 0.16;
+use Types::Standard qw(Maybe);
+use Boxer::Types qw( WorldName DataDir ClassDir NodeDir Suite );
+
+use strictures 2;
+no warnings "experimental::signatures";
 
 =head1 VERSION
 
-Version v1.2.0
+Version v1.4.1
 
 =cut
 
-our $VERSION = version->declare("v1.2.0");
+our $VERSION = "v1.4.1";
 
 # permit callers to sloppily pass undefined values
-sub BUILDARGS
+sub BUILDARGS ( $class, %args )
 {
-	my ( $class, %args ) = @_;
 	delete @args{ grep !defined( $args{$_} ), keys %args };
 	return {%args};
 }
 
-has datadir => (
-	is       => 'lazy',
-	isa      => Maybe [DataDir],
-	coerce   => 1,
+has world => (
+	is       => 'ro',
+	isa      => WorldName,
 	required => 1,
-	default  => sub {undef},
+	default  => sub {'reclass'},
+);
+
+has datadir => (
+	is     => 'lazy',
+	isa    => Maybe [DataDir],
+	coerce => 1,
 );
 
 has suite => (
@@ -62,55 +67,55 @@ has classdir => (
 	isa      => ClassDir,
 	coerce   => 1,
 	required => 1,
-	default  => sub {
-		$_[0]->datadir
-			? $_[0]->datadir->child('classes')
-			: scalar( data_dirs( 'boxer', $_[0]->suite, 'classes' ) );
-	},
 );
 
+sub _build_classdir ($self)
+{
+	my $dir;
+	if ( $self->datadir ) {
+		$self->_logger->trace('Resolving classdir from datadir');
+		$dir = $self->datadir->child('classes');
+	}
+	else {
+		$self->_logger->trace('Resolving classdir from XDG_DATA_DIRS');
+		$dir = scalar data_dirs( 'boxer', $_[0]->suite, 'classes' );
+	}
+	return $dir;
+}
+
 has nodedir => (
 	is       => 'lazy',
 	isa      => NodeDir,
 	coerce   => 1,
 	required => 1,
-	default  => sub { $_[0]->datadir ? $_[0]->datadir->child('nodes') : '.' },
 );
 
-sub run
+sub _build_nodedir ($self)
 {
-	my $self = shift;
-
-	my $data = Load(
-		scalar(
-			capture_stdout {
-				system(
-					'reclass',
-					'-b',
-					'',
-					'-c',
-					$self->classdir,
-					'-u',
-					$self->nodedir,
-					'--inventory',
-				);
-			}
-		)
-	);
-
-	my @parts;
-	for ( keys %{ $data->{nodes} } ) {
-		push @parts,
-			Boxer::Part::Reclass->new(
-			id    => $_,
-			epoch => $self->suite,
-			%{ $data->{nodes}{$_}{parameters} }
-			);
+	my $dir;
+	if ( $self->datadir ) {
+		$self->_logger->trace('Resolving nodedir from datadir');
+		$dir = $self->datadir->child('nodes');
 	}
+	else {
+		$self->_logger->trace('Setting nodedir to current directory');
+		$dir = '.';
+	}
+	return $dir;
+}
 
-	return Boxer::World::Reclass->new(
-		parts => \@parts,
+sub run ($self)
+{
+	my @args = (
+		suite    => scalar $self->suite,
+		classdir => scalar $self->classdir,
+		nodedir  => scalar $self->nodedir,
 	);
+	$self->_logger->info(
+		'Classifying with reclass',
+		$self->_logger->is_debug() ? {@args} : (),
+	);
+	return Boxer->get_world( $self->world )->new(@args);
 }
 
 =head1 AUTHOR
