@@ -10,23 +10,26 @@ Boxer::World - set of software available to install
 
 use v5.14;
 use utf8;
-use strictures 2;
-use version;
 use Role::Commons -all;
+use namespace::autoclean 0.16;
 use autodie;
 
 use Moo;
-use Types::Standard qw(ArrayRef InstanceOf);
+use MooX::StrictConstructor;
+use Types::Standard qw( ArrayRef InstanceOf Maybe );
+use Boxer::Types qw( DataDir );
+with qw(MooX::Role::Logger);
 
-use namespace::autoclean 0.16;
+use strictures 2;
+no warnings "experimental::signatures";
 
 =head1 VERSION
 
-Version v1.2.0
+Version v1.4.1
 
 =cut
 
-our $VERSION = version->declare("v1.2.0");
+our $VERSION = "v1.4.1";
 
 =head1 DESCRIPTION
 
@@ -41,6 +44,12 @@ L<Boxer>.
 
 =cut
 
+has data => (
+	is     => 'lazy',
+	isa    => Maybe [DataDir],
+	coerce => 1,
+);
+
 has parts => (
 	is       => 'ro',
 	isa      => ArrayRef [ InstanceOf ['Boxer::Part'] ],
